##  Why is there only one provider application?
Please see above. The Provider refers to the Application that owns the interface as well as connected Change Management process. Hence it makes sense to have only one "owning" Application.
